log using read, replace text
set mem 900m
set more off

use riders2.dta, clear

sort vehicleid
egen countbac=count(bac08), by(vehicleid)
tab countbac

replace bac08=0 if bac08==.
tab bac08

/*generate interactions*/
gen agesq=age*age
gen ha=helmet*age

gen hd=helmet*driver
gen hm=helmet*male
gen md=male*driver
gen fd=driver*(1-male)
gen fp=(1-male)*(1-driver)
gen mp=male*(1-driver)
gen nhd=(1-helmet)*driver
gen hp=helmet*(1-driver)
gen nhp=(1-helmet)*(1-driver)

/*8 categories for helmet driver male interactions*/

gen hmp=helmet*mp
gen hmd=helmet*md
gen hfp=helmet*fp
gen hfd=helmet*fd
gen uhmp=(1-helmet)*mp
gen uhmd=(1-helmet)*md
gen uhfp=(1-helmet)*fp
gen uhfd=(1-helmet)*fd

sort vehicleid
qui egen hbar=mean(helmet), by(vehicleid)
tab hbar
gen wvflag=1 if hbar==.5


/*Table A*/
sum fatal fatal_inc non_inc poss_inj helmet driver male age bac08 largebike my1990 front side veh1 veh2 night weekend sl55 rural riders2
sum fatal fatal_inc non_inc poss_inj helmet driver male age bac08 largebike my1990 front side veh1 veh2 night weekend sl55 rural riders2 if wvflag==1


/*TABLE ? - SELECTION ON OBSERVABLES*/
 reg helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg helmet driver male age                   , a(vehicleid) cluster(vehicleid)
areg helmet driver male age bac08             , a(vehicleid) cluster(vehicleid)

 reg helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural if wvflag==1,              cluster(vehicleid)
areg helmet driver male age               if wvflag==1     , a(vehicleid) cluster(vehicleid)
areg helmet driver male age bac08          if wvflag==1    , a(vehicleid) cluster(vehicleid)



/*Table B*/
sum fatal if helmet==0
 reg fatal helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg fatal helmet                                                                               , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age                                                               , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age bac08                                                         , a(vehicleid) cluster(vehicleid)

sum fatal if helmet==0 & wvflag==1
 reg fatal helmet          driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural if wvflag==1, cluster(vehicleid)
areg fatal helmet                          if wvflag==1, a(vehicleid) cluster(vehicleid)
areg fatal helmet          driver male age if wvflag==1, a(vehicleid) cluster(vehicleid)
areg fatal helmet  bac08   driver male age if wvflag==1, a(vehicleid) cluster(vehicleid)


/*check with real bac data for both riders*/
areg fatal helmet driver male age bac08    if countbac==2                                                  , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age bac08    if countbac>=1                                                  , a(vehicleid) cluster(vehicleid)


/*Table C*/
gen drXage=driver*age
gen drXmale=driver*male
gen ageXmale=age*male
gen drXmaleXage=driver*male*age

gen hbac=helmet*bac08
gen drXbac=driver*bac08
gen maleXbac=male*bac08
gen ageXbac=age*bac08
gen drXmaleXageXbac=driver*male*age*bac08


areg fatal helmet driver male age                                                  , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age hd hm ha                                         , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age hd hm ha hmd                                     , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age hd hm ha hmd drXmale drXage ageXmale             , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age hd hm ha hmd drXmale drXage ageXmale drXmaleXage , a(vehicleid) cluster(vehicleid)

gen drXbac=driver*bac08
gen maleXbac=male*bac08
gen ageXbac=age*bac08

areg fatal helmet driver male age hd hm ha hmd drXmale drXage ageXmale drXmaleXage bac08 , a(vehicleid) cluster(vehicleid)
areg fatal helmet driver male age hd hm ha hmd drXmale drXage ageXmale drXmaleXageXbac bac08 drXbac maleXbac ageXbac, a(vehicleid) cluster(vehicleid)


/*TABLE BY INJURY*/
 reg fatal     helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg fatal     helmet driver male age                                                               , a(vehicleid) cluster(vehicleid)

 reg fatal_inc helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg fatal_inc helmet driver male age                                                               , a(vehicleid) cluster(vehicleid)

 reg non_inc   helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg non_inc   helmet driver male age                                                               , a(vehicleid) cluster(vehicleid)

 reg poss_inj  helmet driver male age largebike my1990 front side veh1 veh2 night weekend sl55 rural,              cluster(vehicleid)
areg poss_inj  helmet driver male age                                                               , a(vehicleid) cluster(vehicleid)


/*Table D - models by sample traits*/
keep if wvflag==1
sum fatal fatal_inc non_inc poss_inj if helmet==0
areg fatal helmet driver male age          , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age          , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age          , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age          , a(vehicleid) cluster(vehicleid)

	/*smaller bikes*/
sum fatal fatal_inc non_inc poss_inj if largebike==0 & helmet==0
areg fatal helmet driver male age if largebike==0  , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if largebike==0          , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age  if largebike==0         , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age  if largebike==0         , a(vehicleid) cluster(vehicleid)

	/*later model bikes*/
sum fatal fatal_inc non_inc poss_inj if my1990==1 & helmet==0
areg fatal helmet driver male age if my1990==1 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if my1990==1          , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age if my1990==1          , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age if my1990==1           , a(vehicleid) cluster(vehicleid)

	/*Not a frontal or side impact*/
sum fatal fatal_inc non_inc poss_inj if front==0 & side==0 & helmet==0
areg fatal helmet driver male age if front==0 & side==0 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if front==0 & side==0         , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age if front==0 & side==0         , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age if front==0 & side==0         , a(vehicleid) cluster(vehicleid)

	/*daytime*/
sum fatal fatal_inc non_inc poss_inj if night==0 & helmet==0
areg fatal helmet driver male age if night==0 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if night==0         , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age if night==0         , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age if night==0         , a(vehicleid) cluster(vehicleid)

	/*nighttime*/
sum fatal fatal_inc non_inc poss_inj if night==1 & helmet==0
areg fatal helmet driver male age if night==1 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if night==1           , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age  if night==1          , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age  if night==1          , a(vehicleid) cluster(vehicleid)

	/*weekday*/
sum fatal fatal_inc non_inc poss_inj if weekend==0 & helmet==0
areg fatal helmet driver male age if weekend==0 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if weekend==0          , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age if weekend==0          , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age if weekend==0          , a(vehicleid) cluster(vehicleid)

	/*speed limits under 55*/
sum fatal fatal_inc non_inc poss_inj if sl55==0 & helmet==0
areg fatal helmet driver male age if sl55==0 , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if sl55==0          , a(vehicleid) cluster(vehicleid)
areg non_inc helmet driver male age  if sl55==0         , a(vehicleid) cluster(vehicleid)
areg poss_inj helmet driver male age  if sl55==0         , a(vehicleid) cluster(vehicleid)

/*mh law in effect*/
sum fatal fatal_inc non_inc poss_inj if mhl>=0.5 & helmet==0
areg fatal     helmet driver male age if mhl>=0.5  , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if mhl>=0.5           , a(vehicleid) cluster(vehicleid)
areg non_inc   helmet driver male age if mhl>=0.5        , a(vehicleid) cluster(vehicleid)
areg poss_inj  helmet driver male age if mhl>=0.5          , a(vehicleid) cluster(vehicleid)

/*mh law not in effect*/
sum fatal fatal_inc non_inc poss_inj  if mhl< 0.5 & helmet==0
areg fatal     helmet driver male age if mhl< 0.5  , a(vehicleid) cluster(vehicleid)
areg fatal_inc helmet driver male age if mhl< 0.5           , a(vehicleid) cluster(vehicleid)
areg non_inc   helmet driver male age if mhl< 0.5        , a(vehicleid) cluster(vehicleid)
areg poss_inj  helmet driver male age if mhl< 0.5          , a(vehicleid) cluster(vehicleid)


clear
use panel.dta, clear
sort state year
tsset state year
keep if mhl~=.
keep if year>=1988
tab state
tab year
tab tf
tab dtf 
tab ntf


gen dtfmiss=dtf==0
gen ntfmiss=ntf==0
replace dtf=1 if dtf==0
replace ntf=1 if ntf==0
gen ltf=ln(tf)
gen ldtf=ln(dtf)
gen lntf=ln(ntf)
gen lmregs=ln(mregs)
gen tcu=tsq*t


sum tf ntf dtf mhl sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl

/*identify states with changed mhl*/
egen mhlbar=mean(mhl), by(state)
list st_name year mhl if mhlbar~=0 & mhlbar~=1

/*semi-log registration models*/
xi: areg lmregs mhl                                                                  i.year lpop                      , a(state) cluster(state)
xi: areg lmregs mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg lmregs mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t            , a(state) cluster(state)
xi: areg lmregs mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq, a(state) cluster(state)
xi: areg lmregs mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)

/*OLS fatality models*/ 
xi: areg ltf mhl                                                           i.year lpop                      , a(state) cluster(state)
xi: areg ltf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg ltf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg ltf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t            , a(state) cluster(state)
xi: areg ltf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq, a(state) cluster(state)
xi: areg ltf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)
xi: areg ltf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)

xi: areg lntf mhl                                                           i.year lpop                      , a(state) cluster(state)
xi: areg lntf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg lntf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg lntf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t            , a(state) cluster(state)
xi: areg lntf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq, a(state) cluster(state)
xi: areg lntf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)
xi: areg lntf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)

xi: areg ldtf mhl                                                           i.year lpop                      , a(state) cluster(state)
xi: areg ldtf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg ldtf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop                      , a(state) cluster(state)
xi: areg ldtf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t            , a(state) cluster(state)
xi: areg ldtf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq, a(state) cluster(state)
xi: areg ldtf mhl        sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)
xi: areg ldtf mhl lmregs sl65 sl70up zerotol bac_10 bac_08 perse unemp sb1 sb2 gdl i.year lpop i.state|t i.state|tsq i.state|tcu, a(state) cluster(state)

log close


